job "git" {
  datacenters = ["dc1"]
  type = "service"

  constraint {
    attribute = "${attr.cpu.arch}"
    value     = "amd64"
  }

  constraint {
    attribute = "${attr.unique.hostname}"
    value     = "debian1"
  }

  group "gitea" {
    task "server" {
      driver = "docker"
      config {
        image = "gitea/gitea:1.10.3"
        port_map {
          web_port = 3000
          ssh_port = 222
        }
        volumes = [
            "/etc/timezone:/etc/timezone:ro",
            "/etc/localtime:/etc/localtime:ro",
            "/srv/gitea:/data",
        ]
      }

      env {
        "USER_UID" = "1000"
        "USER_GID" = "1000"
        "LOG_LEVEL" = "trace"
      }

      resources {
        memory = 100
        cpu = 100
        network {
          port "web_port" {}
          port "ssh_port" {
            static = 2222
          }
        }
      }

      service {
        tags = [
          "gitea",
          "traefik.enable=true",
          "traefik.frontend.entryPoints=https,http",
          "traefik.frontend.rule=Host:git.deuxfleurs.fr,git.deuxfleurs.org"
        ]
        port = "web_port"
        address_mode = "host"
        name = "gitea"
        check {
          type = "tcp"
          port = "web_port"
          interval = "60s"
          timeout = "5s"
          check_restart {
            limit = 3
            grace = "90s"
            ignore_warnings = false
          }
        }
      }
    }
  }
 }
